@@ -17,29 +17,29 @@ class FlashScope(object):
     The following operations are supported by :class:`FlashScope` instances:
 
     .. describe:: len(f)
-
+    
        Returns the number of items in the flash scope *f*.
 
     .. describe:: f[key]
-
+    
        Returns the item of *f* with key *key*.  Raises a :exc:`KeyError` if
        *key* is not in the flash scope.
 
     .. describe:: f[key] = value
-
+    
        Sets ``f[key]`` to *value*.
 
     .. describe:: del f[key]
-
+    
        Removes ``f[key]`` from *f*.  Raises a :exc:`KeyError` if *key* is not
        in the map.
 
     .. describe:: key in f
-
+    
        Returns ``True`` if *f* has a key *key*, else ``False``.
 
     .. describe:: key not in f
-
+    
        Equivalent to ``not key in f``.
     
     .. describe:: f.now[key] = value
@@ -48,7 +48,7 @@ class FlashScope(object):
     
     .. describe:: f.now(**items)
     
-       Puts the given *items* into *f*.
+       Puts the given *items* into *f* and marks them as *used*.
     """
     
     def __init__(self):
@@ -156,6 +156,9 @@ class FlashScope(object):
     
     def has_key(self, key):
         """Returns ``True`` if there's a value under the given *key*.
+        
+        .. deprecated:: 1.4.2
+           :meth:`has_key()` is deprecated in favor of ``key in f``.
         """
         return self._session.has_key(key)
     
@@ -185,8 +188,8 @@ class FlashScope(object):
         self._update_status(*keys)
     
     def keep(self, *keys):
-        """Prevents the entire current flash or a specific value from being removed
-        on the next request.
+        """Prevents specific values from being removed on the next request.
+        If this method is called with no args, the entire flash is preserved.
         """
         if not keys:
             self._update_status(is_used=False)
@@ -198,7 +201,6 @@ class FlashScope(object):
         """Mark for removal entries that were kept, and delete unkept ones.
         
         .. note::
-        
            This method is called automatically by
            :class:`djangoflash.middleware.FlashMiddleware` when a HTTP
            request hits the server, so never call this method yourself,
